powered by
This function operates the Walsh-8 gate on a conformable input matrix or vector.
Walsh8(n)
a vector/matrix
A matrix or a vector after performing the Walsh-8 gate operation on a conformable input matrix or a vector.
https://en.wikipedia.org/wiki/Quantum_logic_gate http://www2.optics.rochester.edu/~stroud/presentations/muthukrishnan991/LogicGates.pdf https://arxiv.org/pdf/quant-ph/0506219.pdf https://en.wikipedia.org/wiki/Hadamard_transform
# NOT RUN { init() Walsh8(Q$I8) Walsh8(Q$Q000) # }
Run the code above in your browser using DataLab